Cross-platform system helpers and low-level wrappers used internally by the nex crates.
Structs
- File
Desc - Any file descriptor on unix, only sockets on Windows.
Constants
Functions
- close⚠
- Close a raw socket/file descriptor.
- duration_
to_ timespec - Convert a Duration into a platform specific
timespec. - duration_
to_ timeval - Convert a Duration into a platform specific
timeval. - ipv4_
addr_ int - recv_
from - Receives data from a socket, returning the number of bytes read.
- recvfrom⚠
- Call
recvfrom(2)using raw socket arguments. - retry
- send_to
- Sends data to a socket, returning the number of bytes sent.
- sendto⚠
- Call
sendto(2)using raw socket arguments. - sockaddr_
to_ addr - timespec_
to_ duration - Convert a platform specific
timespecinto a Duration. - timeval_
to_ duration - Convert a platform specific
timevalinto a Duration.