close

Function close 

pub unsafe fn close(sock: CSocket)
Close a raw socket/file descriptor.

Safety

sock must be a valid descriptor owned by the caller. It must not be used again after this function returns.